@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -59,6 +59,7 @@ command_classes = {
 package_dir = {'': 'lib'}
 name = 'mysql-connector-python'
 version = '{0}.{1}.{2}'.format(*VERSION[0:3])
+
 extensions = [
     Extension("_mysql_connector",
               sources=[
@@ -68,7 +69,8 @@ extensions = [
                   "src/mysql_connector.c",
                   "src/force_cpp_linkage.cc",
               ],
-              include_dirs=['src/include']),
+              include_dirs=['src/include'],
+    )
 ]
 
 packages = [
@@ -78,6 +80,10 @@ packages = [
     'mysql.connector.locales.eng',
     'mysql.connector.django',
     'mysql.connector.fabric',
+    'mysqlx',
+    'mysqlx.locales',
+    'mysqlx.locales.eng',
+    'mysqlx.protobuf',
 ]
 description = "MySQL driver written in Python"
 long_description = """
@@ -86,8 +92,8 @@ libraries and implements the DB API v2.0 specification (PEP-249).
 """
 author = 'Oracle and/or its affiliates'
 author_email = ''
-maintainer = 'Nuno Mariz'
-maintainer_email = 'nuno.mariz@oracle.com'
+maintainer = 'Geert Vanderkelen'
+maintainer_email = 'geert.vanderkelen@oracle.com'
 cpy_gpl_license = "GNU GPLv2 (with FOSS License Exception)"
 keywords = "mysql db",
 url = 'http://dev.mysql.com/doc/connector-python/en/index.html'
@@ -107,9 +113,6 @@ classifiers = [
     'Programming Language :: Python :: 3.1',
     'Programming Language :: Python :: 3.2',
     'Programming Language :: Python :: 3.3',
-    'Programming Language :: Python :: 3.4',
-    'Programming Language :: Python :: 3.5',
-    'Programming Language :: Python :: 3.6',
     'Topic :: Database',
     'Topic :: Software Development',
     'Topic :: Software Development :: Libraries :: Application Frameworks',
