@@ -1,6 +1,6 @@
 /*
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -363,7 +363,7 @@ MySQL_init(MySQL *self, PyObject *args, PyObject *kwds)
 
     // Initialization expect -1 when parsing arguments failed
     if (!PyArg_ParseTupleAndKeywords(args, kwds,
-                                     "|O!O!O!O!O!O!", kwlist,
+                                     "|O!O!O!O!O!O", kwlist,
                                      &PyBool_Type, &self->buffered_at_connect,
                                      &PyBool_Type, &self->raw_at_connect,
                                      &PyStringType, &self->charset_name,
@@ -393,10 +393,6 @@ MySQL_init(MySQL *self, PyObject *args, PyObject *kwds)
 
     if (auth_plugin)
     {
-        if (strcmp(PyStringAsString(auth_plugin), "") == 0)
-        {
-            auth_plugin= Py_None;
-        }
         if (auth_plugin != Py_None)
         {
             tmp= self->auth_plugin;
@@ -1029,18 +1025,15 @@ MySQL_commit(MySQL *self)
 PyObject*
 MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 {
-	char *host= NULL, *user= NULL, *database= NULL, *unix_socket= NULL;
+	char *host= NULL, *user= NULL, *password= NULL, *database= NULL,
+	     *unix_socket= NULL;
 	char *ssl_ca= NULL, *ssl_cert= NULL, *ssl_key= NULL;
-	PyObject *charset_name, *compress, *ssl_verify_cert, *password;
+	PyObject *charset_name, *compress, *ssl_verify_cert;
 	const char* auth_plugin;
 	unsigned long client_flags= 0;
 	unsigned int port= 3306, tmp_uint;
 	unsigned int protocol= 0;
-#if MYSQL_VERSION_ID >= 50711
-	unsigned int ssl_mode;
-#endif
 	my_bool abool;
-	my_bool ssl_enabled= 0;
 	MYSQL *res;
 
 	static char *kwlist[]=
@@ -1052,11 +1045,7 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 		NULL
     };
 
-#ifdef PY3
     if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzzzkzkzzzO!O!", kwlist,
-#else
-    if (!PyArg_ParseTupleAndKeywords(args, kwds, "|zzOzkzkzzzO!O!", kwlist,
-#endif
                                      &host, &user, &password, &database,
                                      &port, &unix_socket,
                                      &client_flags,
@@ -1117,8 +1106,8 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
     mysql_options(&self->session, MYSQL_OPT_WRITE_TIMEOUT, (char*)&tmp_uint);
 
     if (ssl_ca || ssl_cert || ssl_key) {
-        ssl_enabled= 1;
 #if MYSQL_VERSION_ID > 50703 && MYSQL_VERSION_ID < 50711
+        printf(">>>> %d\n", MYSQL_VERSION_ID);
         {
             abool= 1;
             mysql_options(&self->session, MYSQL_OPT_SSL_ENFORCE, (char*)&abool);
@@ -1126,8 +1115,7 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 #endif
 #if MYSQL_VERSION_ID >= 50711
         {
-            ssl_mode= SSL_MODE_REQUIRED;
-            mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+            mysql_options(&self->session, MYSQL_OPT_SSL_MODE, SSL_MODE_REQUIRED);
         }
 #endif
 
@@ -1135,8 +1123,7 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
         {
 #if MYSQL_VERSION_ID >= 50711
             {
-                ssl_mode= SSL_MODE_VERIFY_IDENTITY;
-                mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+                mysql_options(&self->session, MYSQL_OPT_SSL_MODE, SSL_MODE_VERIFY_IDENTITY);
             }
 #else
             {
@@ -1145,10 +1132,8 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
                               MYSQL_OPT_SSL_VERIFY_SERVER_CERT, (char*)&abool);
             }
 #endif
-          mysql_ssl_set(&self->session, ssl_key, ssl_cert, ssl_ca, NULL, NULL);
-        } else {
-          mysql_ssl_set(&self->session, ssl_key, ssl_cert, NULL, NULL, NULL); 
         }
+        mysql_ssl_set(&self->session, ssl_key, ssl_cert, ssl_ca, NULL, NULL);
     } else {
         // Make sure to not enforce SSL
 #if MYSQL_VERSION_ID > 50703 && MYSQL_VERSION_ID < 50711
@@ -1159,33 +1144,14 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
 #endif
 #if MYSQL_VERSION_ID >= 50711
         {
-            ssl_mode= SSL_MODE_DISABLED;
-            mysql_options(&self->session, MYSQL_OPT_SSL_MODE, &ssl_mode);
+            mysql_options(&self->session, MYSQL_OPT_SSL_ENFORCE, SSL_MODE_DISABLED);
         }
 #endif
     }
 
-    Py_END_ALLOW_THREADS
     if (PyString_Check(self->auth_plugin)) {
         auth_plugin= PyStringAsString(self->auth_plugin);
         mysql_options(&self->session, MYSQL_DEFAULT_AUTH, auth_plugin);
-        if (strcmp(auth_plugin, "sha256_password") == 0 && !ssl_enabled)
-        {
-            PyObject *exc_type= MySQLInterfaceError;
-            PyObject *err_no= PyInt_FromLong(2002);
-            PyObject *err_msg= PyStringFromString("sha256_password requires SSL");
-            PyObject *err_obj= NULL;
-            err_obj= PyObject_CallFunctionObjArgs(exc_type, err_msg, NULL);
-            PyObject_SetAttr(err_obj, PyStringFromString("sqlstate"), Py_None);
-            PyObject_SetAttr(err_obj, PyStringFromString("errno"), err_no);
-            PyObject_SetAttr(err_obj, PyStringFromString("msg"), err_msg);
-            PyErr_SetObject(exc_type, err_obj);
-            Py_XDECREF(exc_type);
-            Py_XDECREF(err_no);
-            Py_XDECREF(err_msg);
-            return NULL;
-        }
-
         if (strcmp(auth_plugin, "mysql_clear_password") == 0)
         {
             abool= 1;
@@ -1193,7 +1159,6 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
                           (char*)&abool);
         }
     }
-    Py_BEGIN_ALLOW_THREADS
 
     if (database && strlen(database) == 0)
     {
@@ -1205,29 +1170,9 @@ MySQL_connect(MySQL *self, PyObject *args, PyObject *kwds)
         client_flags= client_flags & ~CLIENT_CONNECT_WITH_DB;
     }
 
-    if (client_flags & CLIENT_LOCAL_FILES) {
-        abool= 1;
-        mysql_options(&self->session, MYSQL_OPT_LOCAL_INFILE, (unsigned int*)&abool);
-    }
-
-#ifdef PY3
-    res= mysql_real_connect(&self->session, host, user, password, database,
-                            port, unix_socket, client_flags);
-#else
-    char* c_password;
-    if (PyUnicode_Check(password))
-    {
-        PyObject* u_password= PyUnicode_AsUTF8String(password);
-        c_password= PyString_AsString(u_password);
-        Py_DECREF(u_password);
-    }
-    else
-    {
-        c_password= PyString_AsString(password);
-    }
-    res= mysql_real_connect(&self->session, host, user, c_password, database,
-                            port, unix_socket, client_flags);
-#endif
+    res= mysql_real_connect(&self->session,
+                            host, user, password, database,
+    						port, unix_socket, client_flags);
 
     Py_END_ALLOW_THREADS
 
