@@ -41,7 +41,6 @@ from imp import load_source
 from functools import wraps
 from pkgutil import walk_packages
 
-
 LOGGER_NAME = "myconnpy_tests"
 LOGGER = logging.getLogger(LOGGER_NAME)
 PY2 = sys.version_info[0] == 2
@@ -119,6 +118,7 @@ FABRIC_CONFIG = None
 
 __all__ = [
     'MySQLConnectorTests',
+    'MySQLxTests',
     'get_test_names', 'printmsg',
     'LOGGER_NAME',
     'DummySocket',
@@ -303,6 +303,25 @@ def fake_hostname():
         return ''.join(["%02x" % c for c in os.urandom(4)])
 
 
+def get_mysqlx_config(name=None, index=None):
+    """Get MySQLx enabled server configuration for running MySQL server
+
+    If no name is given, then we will return the configuration of the
+    first added.
+    """
+    if not name and not index:
+        return MYSQL_SERVERS[0].xplugin_config.copy()
+
+    if name:
+        for server in MYSQL_SERVERS:
+            if server.name == name:
+                return server.xplugin_config.copy()
+    elif index:
+        return MYSQL_SERVERS[index].xplugin_config.copy()
+
+    return None
+
+
 def get_mysql_config(name=None, index=None):
     """Get MySQL server configuration for running MySQL server
 
@@ -689,6 +708,34 @@ class CMySQLCursorTests(CMySQLConnectorTests):
             self.cleanup_table(cnx, tbl)
 
 
+class MySQLxTests(MySQLConnectorTests):
+
+    def __init__(self, methodName="runTest"):
+        super(MySQLxTests, self).__init__(methodName=methodName)
+
+    def run(self, result=None):
+        if sys.version_info[0:2] == (2, 6):
+            test_method = getattr(self, self._testMethodName)
+            if (getattr(self.__class__, "__unittest_skip__", False) or
+                    getattr(test_method, "__unittest_skip__", False)):
+                # We skipped a class
+                try:
+                    why = (
+                        getattr(self.__class__, '__unittest_skip_why__', '')
+                        or
+                        getattr(test_method, '__unittest_skip_why__', '')
+                    )
+                    self._addSkip(result, why)
+                finally:
+                    result.stopTest(self)
+                return
+
+        if PY2:
+            return super(MySQLxTests, self).run(result)
+        else:
+            return super().run(result)
+
+
 def printmsg(msg=None):
     if msg is not None:
         print(msg)
