@@ -1,5 +1,5 @@
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -343,21 +343,17 @@ class MySQLServerBase(object):
 class MySQLServer(MySQLServerBase):
     """Class for managing a MySQL server"""
 
-    def __init__(self, basedir, topdir, cnf, bind_address, port,
-                 name, datadir=None, tmpdir=None, extra_args={},
-                 unix_socket_folder=None, ssl_folder=None, ssl_ca=None,
-                 ssl_cert=None, ssl_key=None, sharedir=None):
-        self._extra_args = extra_args
+    def __init__(self, basedir, topdir, cnf, bind_address, port, mysqlx_port,
+                 name, datadir=None, tmpdir=None,
+                 unix_socket_folder=None, ssl_folder=None, sharedir=None):
         self._cnf = cnf
         self._option_file = os.path.join(topdir, 'my.cnf')
         self._bind_address = bind_address
         self._port = port
+        self._mysqlx_port = mysqlx_port
         self._topdir = topdir
         self._basedir = basedir
         self._ssldir = ssl_folder or topdir
-        self._ssl_ca = os.path.join(self._ssldir, ssl_ca)
-        self._ssl_cert = os.path.join(self._ssldir, ssl_cert)
-        self._ssl_key = os.path.join(self._ssldir, ssl_key)
         self._datadir = datadir or os.path.join(topdir, 'data')
         self._tmpdir = tmpdir or os.path.join(topdir, 'tmp')
         self._name = name
@@ -376,7 +372,6 @@ class MySQLServer(MySQLServerBase):
         super(MySQLServer, self).__init__(self._basedir,
                                           self._option_file,
                                           sharedir=self._sharedir)
-        self._init_sql = os.path.join(self._topdir, 'init.sql')
 
     def _create_directories(self):
         """Create directory structure for bootstrapping
@@ -390,13 +385,9 @@ class MySQLServer(MySQLServerBase):
         dirs = [
             self._topdir,
             os.path.join(self._topdir, 'tmp'),
+            self._datadir,
+            os.path.join(self._datadir, 'mysql')
         ]
-
-        if self._version[0:3] < (8, 0, 1):
-            dirs.append(self._datadir)
-            if self._version[0:3] < (5, 7, 21):
-                dirs.append(os.path.join(self._datadir, 'mysql'))
-
         for adir in dirs:
             LOGGER.debug("Creating directory %s", adir)
             os.mkdir(adir)
@@ -412,24 +403,16 @@ class MySQLServer(MySQLServerBase):
         cmd = [
             os.path.join(self._sbindir, EXEC_MYSQLD),
             '--no-defaults',
+            '--bootstrap',
             '--basedir=%s' % self._basedir,
             '--datadir=%s' % self._datadir,
+            '--log-warnings=0',
             '--max_allowed_packet=8M',
             '--default-storage-engine=myisam',
             '--net_buffer_length=16K',
             '--tmpdir=%s' % self._tmpdir,
             '--innodb_log_file_size=1Gb',
         ]
-
-        if self._version[0:2] >= (8, 0) or self._version >= (5, 7, 21):
-            cmd.append("--initialize-insecure")
-            cmd.append("--init-file={0}".format(self._init_sql))
-        else:
-            cmd.append("--bootstrap")
-
-        if self._version < (8, 0, 3):
-            cmd.append('--log-warnings=0')
-
         if self._version[0:2] < (5, 5):
             cmd.append('--language={0}/english'.format(self._lc_messages_dir))
         else:
@@ -437,7 +420,7 @@ class MySQLServer(MySQLServerBase):
                 '--lc-messages-dir={0}'.format(self._lc_messages_dir),
                 '--lc-messages=en_US'
             ])
-        if self._version[0:2] >= (5, 1) and self._version < (8, 0, 11):
+        if self._version[0:2] >= (5, 1):
             cmd.append('--loose-skip-ndbcluster')
 
         return cmd
@@ -466,72 +449,63 @@ class MySQLServer(MySQLServerBase):
         extra_sql = [
             "CREATE DATABASE myconnpy;"
         ]
+        insert = (
+            "INSERT INTO mysql.user VALUES ('localhost','root'{0},"
+            "'Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y',"
+            "'Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y',"
+            "'Y','Y','Y','Y','Y','','','','',0,0,0,0,"
+            "@@default_authentication_plugin,'','N',"
+            "CURRENT_TIMESTAMP,NULL{1});"
+        )
+        # MySQL 5.7.5+ creates no user while bootstrapping
+        if self._version[0:3] >= (5, 7, 6):
+            # MySQL 5.7.6+ have extra account_locked col and no password col
+            extra_sql.append(insert.format("", ",'N'"))
+        elif self._version[0:3] >= (5, 7, 5):
+            extra_sql.append(insert.format(",''", ""))
 
-        if self._version > (5, 7, 5) and self._version < (5, 7, 21):
-            # Note: server is running with --skip-grant-tables
-            # (can not user 'CREATE USER' statements).
-            defaults = ("'root'{0}, "
-                        "'Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y',"
-                        "'Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y','Y',"
-                        "'Y','Y','Y','Y','Y','','','','',0,0,0,0,"
-                        "@@default_authentication_plugin,'','N',"
-                        "CURRENT_TIMESTAMP,NULL{1}")
-
-            hosts = ["::1", "127.0.0.1", "localhost"]
-
-            insert = "INSERT INTO mysql.user VALUES {0};".format(
-                ", ".join("('{0}', {{0}})".format(host) for host in hosts))
-
-            if self._version[0:3] >= (5, 7, 6):
-                # No password column, has account_locked column
-                defaults = defaults.format("", ", 'N'")
-            elif self._version[0:3] >= (5, 7, 5):
-                # The password column
-                defaults = defaults.format(", ''", "")
-
-            extra_sql.append(insert.format(defaults))
-        elif self._version[0:3] >= (5, 6, 39) and \
-             self._version[0:3] < (5, 7, 5):
-            # Following required user accounts are created by the server itself:
-            # 'root'@'127.0.0.1', 'root'@'localhost' and 'root'@'::1'
-            # Note: server is running with --skip-grant-tables.
-            pass
-        else:
-            extra_sql.extend([
-                "CREATE USER IF NOT EXISTS 'root'@'127.0.0.1';",
-                "GRANT ALL ON *.* TO 'root'@'127.0.0.1' WITH GRANT OPTION;",
-                "CREATE USER IF NOT EXISTS 'root'@'::1';",
-                "GRANT ALL ON *.* TO 'root'@'::1' WITH GRANT OPTION;"
-            ])
+        insert_localhost = (
+            "INSERT INTO mysql.user SELECT '127.0.0.1', `User`{0},"
+            " `Select_priv`, `Insert_priv`, `Update_priv`, `Delete_priv`,"
+            " `Create_priv`, `Drop_priv`, `Reload_priv`, `Shutdown_priv`,"
+            " `Process_priv`, `File_priv`, `Grant_priv`, `References_priv`,"
+            " `Index_priv`, `Alter_priv`, `Show_db_priv`, `Super_priv`,"
+            " `Create_tmp_table_priv`, `Lock_tables_priv`, `Execute_priv`,"
+            " `Repl_slave_priv`, `Repl_client_priv`, `Create_view_priv`,"
+            " `Show_view_priv`, `Create_routine_priv`, "
+            "`Alter_routine_priv`,"
+            " `Create_user_priv`, `Event_priv`, `Trigger_priv`, "
+            "`Create_tablespace_priv`, `ssl_type`, `ssl_cipher`,"
+            "`x509_issuer`, `x509_subject`, `max_questions`, `max_updates`,"
+            "`max_connections`, `max_user_connections`, `plugin`,"
+            "`authentication_string`, `password_expired`,"
+            "`password_last_changed`, `password_lifetime`{1} FROM mysql.user "
+            "WHERE `user` = 'root' and `host` = 'localhost';"
+        )
+        # MySQL 5.7.4+ only creates root@localhost
+        if self._version[0:3] >= (5, 7, 6):
+            extra_sql.append(insert_localhost.format("", ",`account_locked`"))
+        elif self._version[0:3] >= (5, 7, 4):
+            extra_sql.append(insert_localhost.format(",`Password`", ""))
 
         bootstrap_log = os.path.join(self._topdir, 'bootstrap.log')
         try:
             self._create_directories()
             cmd = self._get_bootstrap_cmd()
             sql = ["USE mysql;"]
-
-            if self._version[0:2] >= (8, 0) or self._version >= (5, 7, 21):
-                test_sql = open(self._init_sql, "w")
-                test_sql.write("\n".join(extra_sql))
-                test_sql.close()
-            else:
-                for filename in script_files:
-                    full_path = os.path.join(self._scriptdir, filename)
-                    LOGGER.debug("Reading SQL from '%s'", full_path)
-                    with open(full_path, 'r') as fp:
-                        sql.extend([line.strip() for line in fp.readlines()])
-
+            for filename in script_files:
+                full_path = os.path.join(self._scriptdir, filename)
+                LOGGER.debug("Reading SQL from '%s'", full_path)
+                with open(full_path, 'r') as fp:
+                    sql.extend([line.strip() for line in fp.readlines()])
+            sql.extend(extra_sql)
             fp_log = open(bootstrap_log, 'w')
-            if self._version[0:2] < (8, 0) or self._version < (5, 7, 21):
-                sql.extend(extra_sql)
-                prc = subprocess.Popen(cmd, stdin=subprocess.PIPE,
-                                       stderr=subprocess.STDOUT,
-                                       stdout=fp_log)
-                prc.communicate('\n'.join(sql) if sys.version_info[0] == 2
-                                else bytearray('\n'.join(sql), 'utf8'))
+            prc = subprocess.Popen(cmd, stdin=subprocess.PIPE,
+                                   stderr=subprocess.STDOUT, stdout=fp_log)
+            if sys.version_info[0] == 2:
+                prc.communicate('\n'.join(sql))
             else:
-                prc = subprocess.call(cmd, stderr=subprocess.STDOUT,
-                                      stdout=fp_log)
+                prc.communicate(bytearray('\n'.join(sql), 'utf8'))
             fp_log.close()
         except OSError as err:
             raise MySQLBootstrapError(
@@ -567,7 +541,13 @@ class MySQLServer(MySQLServerBase):
         """Return the unix socket of the server"""
         return self._unix_socket
 
-    def update_config(self, **kwargs):
+    def start(self):
+        """Start a MySQL server"""
+        if self.check_running():
+            LOGGER.error("MySQL server '{name}' already running".format(
+                name=self.name))
+            return
+
         options = {
             'name': self._name,
             'basedir': _convert_forward_slash(self._basedir),
@@ -575,41 +555,19 @@ class MySQLServer(MySQLServerBase):
             'tmpdir': _convert_forward_slash(self._tmpdir),
             'bind_address': self._bind_address,
             'port': self._port,
+            'mysqlx_port': self._mysqlx_port,
+            'mysqlx_plugin': 'mysqlx.so' if os.name == 'posix' else 'mysqlx',
             'unix_socket': _convert_forward_slash(self._unix_socket),
             'ssl_dir': _convert_forward_slash(self._ssldir),
-            'ssl_ca': _convert_forward_slash(self._ssl_ca),
-            'ssl_cert': _convert_forward_slash(self._ssl_cert),
-            'ssl_key': _convert_forward_slash(self._ssl_key),
             'pid_file': _convert_forward_slash(self._pid_file),
             'serverid': self._serverid,
             'lc_messages_dir': _convert_forward_slash(
                 self._lc_messages_dir),
-            'ssl': 1,
         }
-
-        for arg in self._extra_args:
-            if self._version < arg["version"]:
-                options.update(dict([(key, '') for key in
-                                     arg["options"].keys()]))
-            else:
-                options.update(arg["options"])
-        options.update(**kwargs)
         try:
             fp = open(self._option_file, 'w')
             fp.write(self._cnf.format(**options))
             fp.close()
-        except Exception as ex:
-            LOGGER.error("Failed to write config file {0}".format(ex))
-            sys.exit(1)
-
-    def start(self, **kwargs):
-        if self.check_running():
-            LOGGER.error("MySQL server '{name}' already running".format(
-                name=self.name))
-            return
-
-        self.update_config(**kwargs)
-        try:
             self._start_server()
             for i in range(10):
                 if self.check_running():
