@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -321,7 +321,7 @@ class MySQLCursorTests(tests.TestsCursor):
         self.cur = cursor.MySQLCursor(self.cnx)
         self.assertRaises(StopIteration, self.cur.__next__)
         self.cur.execute("SELECT BINARY 'ham'")
-        exp = ('ham',)
+        exp = (b'ham',)
         self.assertEqual(exp, next(self.cur))
         self.cur.close()
 
@@ -361,8 +361,6 @@ class MySQLCursorTests(tests.TestsCursor):
             datetime.time(20, 3, 23),
             st_now,
             datetime.timedelta(hours=40, minutes=30, seconds=12),
-            'foo %(t)s',
-            'foo %(s)s',
         )
         exp = (
             b'NULL',
@@ -384,8 +382,6 @@ class MySQLCursorTests(tests.TestsCursor):
             b"'" + time.strftime('%Y-%m-%d %H:%M:%S', st_now).encode('ascii')
             + b"'",
             b"'40:30:12'",
-            b"'foo %(t)s'",
-            b"'foo %(s)s'",
         )
 
         self.cnx = connection.MySQLConnection(**tests.get_mysql_config())
@@ -425,32 +421,28 @@ class MySQLCursorTests(tests.TestsCursor):
             'p': datetime.time(20, 3, 23),
             'q': st_now,
             'r': datetime.timedelta(hours=40, minutes=30, seconds=12),
-            's': 'foo %(t)s',
-            't': 'foo %(s)s',
         }
         exp = {
-            b'a': b'NULL',
-            b'b': b'128',
-            b'c': b'1281288',
-            b'd': repr(float(3.14)) if PY2 else b'3.14',
-            b'e': b"'3.14'",
-            b'f': b"'back\\\\slash'",
-            b'g': b"'newline\\n'",
-            b'h': b"'return\\r'",
-            b'i': b"'\\'single\\''",
-            b'j': b'\'\\"double\\"\'',
-            b'k': b"'windows\\\x1a'",
-            b'l': b"'Strings are sexy'",
-            b'm': b"'\xe8\x8a\xb1'",
-            b'n': b"'2008-05-07 20:01:23'",
-            b'o': b"'2008-05-07'",
-            b'p': b"'20:03:23'",
-            b'q': b"'" +
+            b'%(a)s': b'NULL',
+            b'%(b)s': b'128',
+            b'%(c)s': b'1281288',
+            b'%(d)s': repr(float(3.14)) if PY2 else b'3.14',
+            b'%(e)s': b"'3.14'",
+            b'%(f)s': b"'back\\\\slash'",
+            b'%(g)s': b"'newline\\n'",
+            b'%(h)s': b"'return\\r'",
+            b'%(i)s': b"'\\'single\\''",
+            b'%(j)s': b'\'\\"double\\"\'',
+            b'%(k)s': b"'windows\\\x1a'",
+            b'%(l)s': b"'Strings are sexy'",
+            b'%(m)s': b"'\xe8\x8a\xb1'",
+            b'%(n)s': b"'2008-05-07 20:01:23'",
+            b'%(o)s': b"'2008-05-07'",
+            b'%(p)s': b"'20:03:23'",
+            b'%(q)s': b"'" +
             time.strftime('%Y-%m-%d %H:%M:%S', st_now).encode('ascii')
             + b"'",
-            b'r': b"'40:30:12'",
-            b's': b"'foo %(t)s'",
-            b't': b"'foo %(s)s'",
+            b'%(r)s': b"'40:30:12'",
         }
 
         self.cnx = connection.MySQLConnection(**tests.get_mysql_config())
@@ -554,7 +546,7 @@ class MySQLCursorTests(tests.TestsCursor):
         self.assertTrue(tests.cmp_result(exp, self.cur._warnings))
 
         self.cur.execute("SELECT BINARY 'ham'")
-        exp = [('ham',)]
+        exp = [(b'ham',)]
         self.assertEqual(exp, self.cur.fetchall())
         self.cur.close()
 
@@ -826,7 +818,7 @@ class MySQLCursorTests(tests.TestsCursor):
         self.cnx = connection.MySQLConnection(**tests.get_mysql_config())
         self.cur = self.cnx.cursor()
         self.cur.execute("SELECT BINARY 'ham'")
-        exp = ('ham',)
+        exp = (b'ham',)
         self.assertEqual(exp, self.cur.fetchone())
         self.assertEqual(None, self.cur.fetchone())
         self.cur.close()
@@ -1113,7 +1105,7 @@ class MySQLCursorPreparedTests(tests.TestsCursor):
 
     def test_callproc(self):
         cur = self.cnx.cursor(cursor_class=cursor.MySQLCursorPrepared)
-        self.assertRaises(errors.NotSupportedError, cur.callproc, None)
+        self.assertRaises(errors.NotSupportedError, cur.callproc)
 
     def test_close(self):
         cur = self.cnx.cursor(cursor_class=cursor.MySQLCursorPrepared)
@@ -1232,7 +1224,7 @@ class MySQLCursorPreparedTests(tests.TestsCursor):
         self.assertEqual(3, cur.rowcount)
 
         cur.execute(stmt_select)
-        self.assertEqual([(1, '100'), (2, '200'), (3, '300')],
+        self.assertEqual([(1, b'100'), (2, b'200'), (3, b'300')],
                          cur.fetchall(), "Multi insert test failed")
 
         data = [(2,), (3,)]
@@ -1255,8 +1247,8 @@ class MySQLCursorPreparedTests(tests.TestsCursor):
             return row
         cur._fetch_row = _fetch_row
 
-        cur._test_fetch_row = [('ham',)]
-        self.assertEqual(('ham',), cur.fetchone())
+        cur._test_fetch_row = [(b'ham',)]
+        self.assertEqual((b'ham',), cur.fetchone())
         self.assertEqual(None, cur.fetchone())
 
     def test_fetchmany(self):
