@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2009, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
 
 # MySQL Connector/Python is licensed under the terms of the GPLv2
 # <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
@@ -96,11 +96,13 @@ else:
     tests.TEST_BUILD_DIR = os.path.join(_TOPDIR, 'build', 'testing')
     sys.path.insert(0, tests.TEST_BUILD_DIR)
 
+
 # MySQL option file template. Platform specifics dynamically added later.
 MY_CNF = """
 # MySQL option file for MySQL Connector/Python tests
-[mysqld-8.0]
-information-schema-stats=LATEST
+[mysqld-5.7]
+plugin-load={mysqlx_plugin}
+loose_mysqlx_port={mysqlx_port}
 
 [mysqld-5.6]
 innodb_compression_level = 0
@@ -146,17 +148,17 @@ ssl
 # Platform specifics
 if os.name == 'nt':
     MY_CNF += '\n'.join((
-        "ssl-ca = {ssl_ca}",
-        "ssl-cert = {ssl_cert}",
-        "ssl-key = {ssl_key}",
+        "ssl-ca = {ssl_dir}\\\\tests_CA_cert.pem",
+        "ssl-cert = {ssl_dir}\\\\tests_server_cert.pem",
+        "ssl-key = {ssl_dir}\\\\tests_server_key.pem",
     ))
     MYSQL_DEFAULT_BASE = os.path.join(
         "C:/", "Program Files", "MySQL", "MySQL Server 5.6")
 else:
     MY_CNF += '\n'.join((
-        "ssl-ca = {ssl_ca}",
-        "ssl-cert = {ssl_cert}",
-        "ssl-key = {ssl_key}",
+        "ssl-ca = {ssl_dir}/tests_CA_cert.pem",
+        "ssl-cert = {ssl_dir}/tests_server_cert.pem",
+        "ssl-key = {ssl_dir}/tests_server_key.pem",
         "innodb_flush_method = O_DIRECT",
     ))
     MYSQL_DEFAULT_BASE = os.path.join('/', 'usr', 'local', 'mysql')
@@ -284,6 +286,12 @@ _UNITTESTS_CMD_ARGS = {
         'type_optparse': int,
     },
 
+    ('', '--mysqlx-port'): {
+        'dest': 'mysqlx_port', 'metavar': 'NUMBER', 'default': 33060,
+        'type': int, 'help': 'First TCP/IP port to use for mysqlx protocol.',
+        'type_optparse': int,
+    },
+
     ('', '--unix-socket'): {
         'dest': 'unix_socket_folder', 'metavar': 'NAME',
         'help': 'Folder where UNIX Sockets will be created'
@@ -332,12 +340,6 @@ _UNITTESTS_CMD_ARGS = {
         'default': 'xmlrpc',
         'help': ("Protocol to talk to MySQL Fabric")
     },
-
-    ('', '--extra-compile-args'): {
-        'dest': 'extra_compile_args', 'metavar': 'NAME',
-        'default': None,
-        'help': ("Extra compile args for the C extension")
-    },
 }
 
 
@@ -601,7 +603,6 @@ def setup_stats_db(cnx):
 def init_mysql_server(port, options):
     """Initialize a MySQL Server"""
     name = 'server{0}'.format(len(tests.MYSQL_SERVERS) + 1)
-    extra_args = []
 
     try:
         mysql_server = mysqld.MySQLServer(
@@ -610,13 +611,10 @@ def init_mysql_server(port, options):
             cnf=MY_CNF,
             bind_address=options.bind_address,
             port=port,
+            mysqlx_port=options.mysqlx_port,
             unix_socket_folder=options.unix_socket_folder,
             ssl_folder=os.path.abspath(tests.SSL_DIR),
-            ssl_ca="tests_CA_cert.pem",
-            ssl_cert="tests_server_cert.pem",
-            ssl_key="tests_server_key.pem",
             name=name,
-            extra_args=extra_args,
             sharedir=options.mysql_sharedir)
     except tests.mysqld.MySQLBootstrapError as err:
         LOGGER.error("Failed initializing MySQL server "
@@ -669,6 +667,14 @@ def init_mysql_server(port, options):
         'connection_timeout': 10,
     }
 
+    mysql_server.xplugin_config = {
+        'host': options.host,
+        'port': options.mysqlx_port,
+        'user': 'root',
+        'password': '',
+        'schema': 'myconnpy'
+    }
+
     # Bootstrap and start a MySQL server
     if have_to_bootstrap:
         LOGGER.info("Bootstrapping MySQL server '{name}'".format(name=name))
@@ -768,8 +774,7 @@ def main():
     tests.MYSQL_CAPI = options.mysql_capi
     if not options.skip_install:
         tests.install_connector(_TOPDIR, tests.TEST_BUILD_DIR,
-                                options.mysql_capi,
-                                options.extra_compile_args)
+                                options.mysql_capi)
 
     # Which tests cases to run
     testcases = []
